#!/usr/bin/python

from gimpfu import *

def ShadowLayer(image, layer):
	image.resize(image.width + 16, image.height + 16, 1, 1)
	pdb.script_fu_drop_shadow(image, layer, 8, 8, 15, (0, 0, 0), 60,
			False)

def MythVideoPopup(width, height, gimpFilename, pngFilename, autosave,
		interactive):
	if len(gimpFilename) and gimpFilename[-4:].lower() != ".xcf":
		gimpFilename += ".xcf"

	if len(pngFilename) and pngFilename[-4:].lower() != ".png":
		pngFilename += ".png"

	borderWidth = 5
	imageWidth = width + 2 * borderWidth
	imageHeight = height + 2 * borderWidth
	image = gimp.Image(imageWidth, imageHeight, RGB)

	image.disable_undo()
	gimp.context_push()

	layerBackground = gimp.Layer(image, "background", imageWidth,
			imageHeight, RGBA_IMAGE, 100, NORMAL_MODE)
	image.add_layer(layerBackground, 1)

	# white rect
	pdb.gimp_edit_clear(layerBackground)
	gimp.set_foreground((255, 255, 255))
	pdb.script_fu_selection_rounded_rectangle(image, layerBackground,
			14.0, False)
	pdb.gimp_edit_fill(layerBackground, BACKGROUND_FILL)
	pdb.script_fu_add_bevel(image, layerBackground, borderWidth,
			False, False)
	pdb.plug_in_antialias(image, layerBackground)

	# black rect
	layerBlackBox = gimp.Layer(image, "black box", imageWidth,
			imageHeight, RGBA_IMAGE, 100, NORMAL_MODE)
	image.add_layer(layerBlackBox, -1)
	pdb.gimp_edit_clear(layerBlackBox)
	pdb.script_fu_selection_rounded_rectangle(image, layerBlackBox,
			14.0, False)
	pdb.gimp_selection_shrink(image, borderWidth)
	gimp.set_foreground((0, 0, 0))
	pdb.gimp_edit_fill(layerBlackBox, FOREGROUND_FILL)
	pdb.plug_in_antialias(image, layerBlackBox)

	pdb.gimp_selection_layer_alpha(layerBackground)

	ShadowLayer(image, layerBackground)

	gimp.context_pop()
	image.enable_undo()

	pdb.gimp_selection_none(image)

	if len(gimpFilename):
		image.filename = gimpFilename

	if interactive:
		gimp.Display(image)

	if len(gimpFilename) and len(pngFilename) and autosave:
		pdb.gimp_file_save(image, layerBackground, gimpFilename,
				gimpFilename)

#		layerFlat = pdb.gimp_image_flatten(image)
		layerFlat = pdb.gimp_image_merge_visible_layers(image, CLIP_TO_IMAGE)

		pdb.file_png_save2(
				image,
				layerFlat,
				pngFilename, pngFilename,
				False, # adam7
				9,
				0, # bKGD
				0, # gAMA
				0, # oFFs
				0, # pHYs
				0, # tIME
				0, # comment
				0) # trans

	return image

def mythvideo_popup(bb_width, bb_height, gimpFilename, pngFilename,
		autosave, interactive):
	MythVideoPopup(bb_width, bb_height, gimpFilename, pngFilename, autosave,
			interactive)
	if interactive:
		gimp.displays_flush()

register("mythvideo-popup",
		"MythVideo Popup",
		"Create a basic MythVideo popup box",
		"",
		"",
		"",
		"Create Popup",
		"",
		[
			(PF_SPINNER, "bb_width", "Pre-border width", 400, (0, 1920, 50)),
			(PF_SPINNER, "bb_height", "Pre-border height", 200, (0, 1200, 50)),
			(PF_STRING, "gimp_name", "GIMP filename", ""),
			(PF_STRING, "png_name", "PNG export filename", ""),
			(PF_BOOL, "autosave", "Save", False),
			(PF_BOOL, "interactive", "interactive", True),
		],
		[],
		mythvideo_popup,
        menu="<Toolbox>/Xtns/MythTV/MythVideo")

main()



#!/usr/bin/python

import sys
import os
import socket
import MySQLdb
from optparse import OptionParser

DB_USER = 'mythtv'
DB_PASSWORD = 'mythtv'
DB_HOST = 'localhost'
DB_DATABASE = 'mythconverg'

BACKUP = '~/.mythvideo_script.rc'

def __open_db():
	conn = MySQLdb.connect(host = DB_HOST, user = DB_USER,
			passwd = DB_PASSWORD, db = DB_DATABASE)
	return conn

def get_db_setting(cur, name, hostname):
	cur.execute("SELECT data FROM settings WHERE "
			"value = %s AND hostname = %s", (name, hostname))
	row = cur.fetchone()
	if (row and len(row)):
		return row[0]
	return None

def set_db_setting(cur, name, value, hostname):
	cur.execute("DELETE FROM settings WHERE value = %s AND hostname = %s",
			(name, hostname))
	cur.execute("INSERT INTO settings (value, data, hostname) "
	            "VALUES (%s, %s, %s)", (name, value, hostname))

def install(script):
	backupfile = os.path.expanduser(BACKUP)
	if os.path.exists(backupfile):
		print('Error: a backup already exists, will not install over.')
		return

	try:
		hostname = socket.gethostname()
		print("hostname = %s" % (hostname,))
		conn = __open_db()
		c = conn.cursor()
		old_movie_list = get_db_setting(c, 'MovieListCommandLine', hostname)
		old_poster = get_db_setting(c, 'MoviePosterCommandLine', hostname)
		old_data = get_db_setting(c, 'MovieDataCommandLine', hostname)

		if (old_movie_list and old_poster and old_data):
			f = open(backupfile, 'w')
			f.writelines(
			"""MovieListCommandLine=%(movie_list_cmd)s
MoviePosterCommandLine=%(movie_poster_cmd)s
MovieDataCommandLine=%(movie_data_cmd)s
""" % { 'movie_list_cmd' : old_movie_list,
	    'movie_poster_cmd' : old_poster,
		'movie_data_cmd' : old_data})
			f.close()

			set_db_setting(c, 'MovieListCommandLine',
					'%s -M' % (script,), hostname)
			set_db_setting(c, 'MoviePosterCommandLine',
					'%s -P' % (script,), hostname)
			set_db_setting(c, 'MovieDataCommandLine',
					'%s -D' % (script,), hostname)
		conn.commit()
		print('Installation complete, use --uninstall to revert.')
	except:
		raise

def uninstall():
	backupfile = os.path.expanduser(BACKUP)
	if not os.path.exists(backupfile):
		print('Error: backup file %s not found, unable to restore.' %
				(backupfile,))
		return

	try:
		hostname = socket.gethostname()

		conn = __open_db()
		c = conn.cursor()

		f = open(backupfile, "r")
		for line in f:
			line = line.strip()
			if len(line):
				(value, data) = line.split('=', 1)
				set_db_setting(c, value, data, hostname)

		os.unlink(backupfile)
		conn.commit()
		print('Restore now complete.')
	except:
		raise

def main():
	parser = OptionParser()

	parser.add_option("--install", type="string", dest="install",
			metavar="SCRIPT",
			help="Installs SCRIPT as the MythVideo external script for "
			"poster/data/search.")
	parser.add_option("--uninstall", action="store_true", dest="uninstall",
			help="Undoes what --install did.")

	parser.add_option("--db-user", type="string", dest="db_user",
			help="Database user.")
	parser.add_option("--db-host", type="string", dest="db_host",
			help="Database host.")
	parser.add_option("--db-password", type="string", dest="db_password",
			help="Database password.")
	parser.add_option("--db-database", type="string", dest="db_database",
			help="Database.")

	parser.add_option("--script-dir", type="string", dest="script_dir",
			default="/usr/local/share/mythtv/mythvideo/scripts",
			help="Script dir.")
	(options, args) = parser.parse_args()

	global DB_USER, DB_PASSWORD, DB_HOST, DB_DATABASE
	if options.db_user:
		DB_USER = options.db_user
	if options.db_host:
		DB_HOST = options.db_host
	if options.db_password:
		DB_PASSWORD = options.db_password
	if options.db_password:
		DB_DATABASE = options.db_database

	if options.install:
		inst_script = options.install
		if not os.path.exists(inst_script):
			inst_script = os.path.join(options.script_dir, options.install)

		if not os.path.exists(inst_script):
			print("Error: script not found '%s'" % (inst_script,))
			sys.exit(1)

		inst_script = os.path.abspath(inst_script)
		install(inst_script)
	elif options.uninstall:
		uninstall()
	else:
		parser.print_help()

if __name__ == '__main__':
	main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# ----------------------
# Name: bliptv_exceptions - Custom exceptions used or raised by bliptv_api
# Python Script
# Author:  R.D. Vaughan
# Purpose:  Custom exceptions used or raised by bliptv_api
#
# License:Creative Commons GNU GPL v2
# (http://creativecommons.org/licenses/GPL/2.0/)
#-------------------------------------
__title__ ="bliptv_exceptions - Custom exceptions used or raised by bliptv_api";
__author__="R.D. Vaughan"
__version__="v0.2.0"
# 0.1.0 Initial development
# 0.1.1 Documentation review
# 0.2.0 Public release

__all__ = ["BliptvUrlError", "BliptvHttpError", "BliptvRssError", "BliptvVideoNotFound", "BliptvXmlError"]

class BliptvBaseError(Exception):
    pass

class BliptvUrlError(BliptvBaseError):
    def __repr__(self):    # Display the type of error
        return None
    # end __repr__

class BliptvHttpError(BliptvBaseError):
    def __repr__(self):    # Display the type of error
        return None
    # end __repr__

class BliptvRssError(BliptvBaseError):
    def __repr__(self):
        return None
    # end __repr__

class BliptvVideoNotFound(BliptvBaseError):
    def __repr__(self):
        return None
    # end __repr__

class BliptvXmlError(BliptvBaseError):
    def __repr__(self):
        return None
    # end __repr__



#!/usr/bin/python

import sys
import os
import time
import shutil
import BaseHTTPServer
from optparse import OptionParser
from mythvideo_test import HTTP_PORT

GET_DELAY=0

class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
	def do_HEAD(self):
		self.__send_head(False)

	def do_GET(self):
		f = self.__send_head(True)
		self.log_message("Sleeping for %d" % (GET_DELAY,))
		time.sleep(GET_DELAY)
		if f:
			shutil.copyfileobj(f, self.wfile)
			f.close()

	def __send_head(self, open_file):
		filename = os.path.normpath(os.getcwd() + self.path)
		if self.__file_readable(filename):
			f = None
			if open_file:
				try:
					f = open(filename, 'rb')
				except IOError:
					self.send_error(404, "File not found")
					return None

			stats = os.stat(filename)
			self.send_response(200)
			self.send_header("Content-type", 'image/png')
			self.send_header("Content-Length", str(stats[6]))
			self.send_header("Last-Modified", self.date_time_string(stats[8]))
			self.end_headers()
			return f
		else:
			self.send_error(404, "File not found")
			return None

	def __file_readable(self, filepath):
		return os.path.isfile(filepath)

def main():
	parser = OptionParser()
	parser.add_option("-d", "--delay", type="int", dest="delay",
			help="Causes image GETs to wait DELAY seconds before returning "
			     "the image.", metavar="DELAY")
	parser.add_option("-p", "--port", type="int", dest="port",
			          help="Port to bind to.")
	(options, args) = parser.parse_args()

	bind_port = HTTP_PORT

	if options.port:
		bind_port = options.port

	if options.delay:
		global GET_DELAY
		GET_DELAY = int(options.delay)

	try:
		httpd = BaseHTTPServer.HTTPServer(('', bind_port), MyRequestHandler)
		print('Waiting for requests')
		httpd.serve_forever()
	except KeyboardInterrupt:
		print("Done.")

if __name__ == '__main__':
	main()
